@@ -574,7 +574,7 @@ void SmoothModels(Tree T, Tree Parent, CaseNo Fp, CaseNo Lp);
 double ErrVariance(double *Model, CaseNo Fp, CaseNo Lp, double *Err);
 double Smooth(double PVal, int PCases, double LVal, int LCases);
 void FindErrors(Tree T, CaseNo Fp, CaseNo Lp);
-void CValToStr(ContValue CV, Attribute Att, String DS);
+void CValToStr(ContValue CV, Attribute Att, String DS, size_t DS_size);
 Boolean FindWeakestSubtree(Tree T);
 float TreeValue(Tree T, DataRec Case);
 float MedianResid(CaseNo Fp, CaseNo Lp, double Want);
@@ -619,9 +619,9 @@ int Denominator(ContValue Val);
 int FracBase(Attribute Att);
 int GetInt(String S, int N);
 int DateToDay(String DS);
-void DayToDate(int DI, String Date);
+void DayToDate(int DI, String Date, size_t DT_size);
 int TimeToSecs(String TS);
-void SecsToTime(int Secs, String Time);
+void SecsToTime(int Secs, String Time, size_t DT_size);
 void SetTSBase(int y);
 int TStampToMins(String TS);
 void Cleanup(void);
